# Neo SHell emulator (NEOSH)

It is an attempt to try making a shell in python. Has autocomplete as well as a fancy new theme. If there are any issues please add it in the issues section. 

First do pip3 install -r requirements.txt then do python3 main.py
